@@ -1,4 +1,4 @@
-from .common import RouterUtils, Utils, Base64Utils
+from .common import RouterUtils, Utils, Base64Utils, FileUtils
 from .config.logger import LoggerFactory
 from .db.db_utils import DbUtils
 from .db.models import (
@@ -8,7 +8,7 @@ from .db.models import (
 
 
 __all__ = [
-    "Utils", "RouterUtils", "Base64Utils",
+    "Utils", "RouterUtils", "Base64Utils", "FileUtils",
     "DbUtils",
     "AutoRepr",
     "Object",
