@@ -15,15 +15,16 @@ from typing import List, Union, Any, Dict, Optional, Literal
 
 import inflection
 from cryptography.fernet import Fernet
-from fastapi import APIRouter, Path
+from fastapi import APIRouter, Path, UploadFile
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import Response
 from jinja2 import Template
 from jose import jwt
 from passlib.context import CryptContext
-from starlette.exceptions import HTTPException
 from starlette.requests import Request
 
+from appodus_utils.exception.exceptions import ForbiddenException, UnauthorizedException
+
 # Constants
 CHUNK_SIZE = 64 * 1024  # 64 KB for streaming
 MAX_ATTACHMENT_SIZE = 10 * 1024 * 1024
@@ -354,6 +355,7 @@ class Utils:
             )
 
 client_secret_encryption_key = os.getenv('CLIENT_SECRET_ENCRYPTION_KEY')
+client_request_expires_seconds: int = int(os.getenv('CLIENT_REQUEST_EXPIRES_SECONDS', 300))
 fernet = Fernet(client_secret_encryption_key)
 
 class ClientUtils:
@@ -402,18 +404,18 @@ class ClientUtils:
 
     @staticmethod
     async def verify_signature(request: Request, client_secret: str):
-        api_key = request.headers.get("x-api-key")
+        client_id = request.headers.get("x-client-id")
         signature = request.headers.get("x-signature")
         timestamp = request.headers.get("x-timestamp")
 
-        if not all([api_key, signature, timestamp]):
-            raise HTTPException(status_code=401, detail="Missing headers")
-
-        if abs(int(time.time()) - int(timestamp)) > 300:
-            raise HTTPException(status_code=401, detail="Request expired")
-
         if not client_secret:
-            raise HTTPException(status_code=403, detail="Invalid API key")
+            raise ForbiddenException(message="Invalid Client ID")
+
+        if not all([client_id, signature, timestamp]):
+            raise UnauthorizedException(message="Missing headers")
+
+        if abs(int(time.time()) - int(timestamp)) > client_request_expires_seconds:
+            raise UnauthorizedException(message="Request expired")
 
         body = await request.body()
         path = str(request.url.path)
@@ -422,7 +424,7 @@ class ClientUtils:
         expected_signature = ClientUtils.compute_signature(client_secret, method, path, timestamp, body.decode())
 
         if not hmac.compare_digest(expected_signature, signature):
-            raise HTTPException(status_code=403, detail="Invalid signature")
+            raise ForbiddenException(message="Invalid signature")
 
 class RouterUtils:
 
@@ -440,6 +442,23 @@ class RouterUtils:
                     if tag in route.tags:
                         route.tags.remove(tag)
 
+class FileUtils:
+
+    @staticmethod
+    async def get_file_size(file: UploadFile) -> int:
+        """
+        Determines the total size of the uploaded file in bytes.
+
+        Args:
+            file (UploadFile): The file to check.
+
+        Returns:
+            int: File size in bytes.
+        """
+        file.file.seek(0, 2)  # Seek to end
+        size = file.file.tell()
+        file.file.seek(0)  # Reset to beginning
+        return size
 
 class Base64Utils:
     @staticmethod
